#ifndef INTERFACE_HPP
#define INTERFACE_HPP

/*
 * Classes definitions for OpenGL rendering area.
 */

#include <gtkmm/window.h>
#include <gtkmm/drawingarea.h>
#include <gtkglmm.h>

#include "errors.hpp"

/* Namespace for the interface. */
namespace Interface {
  /* OpenGL drawing area. */
  class GlDrawingArea: public Gtk::DrawingArea,
                       public Gtk::GL::Widget<GlDrawingArea> {
    public:
      /* Default constructor. */
      GlDrawingArea ();

      /* Destructor. */
      virtual ~GlDrawingArea ();

    protected:
      /* -- Handlers: */

      /* Window initialisation. */
      virtual void on_realize ();

      /* Displaying the window. */
      virtual bool on_expose_event (GdkEventExpose* event);

      /* Resizing the window. */
      virtual bool on_configure_event (GdkEventConfigure* event);
  };

/* ----------------------------------------------------------------------- */

  /* Classe pour la fenetre principale. */
  class MainWindow: public Gtk::Window {
    public:
      /* Default constructor. */
      MainWindow ();

      /* Destructor. */
      virtual ~MainWindow ();

    protected:
      /* -- Handlers: */

      /* Dealing with keyboard events. */
      bool on_key_release (GdkEventKey* evenement);

      /* When switching into full-screen mode. */
      bool on_window_state_event (GdkEventWindowState *pEven);

      /* -- Child widgets: */

      /* OpenGL area. */
      GlDrawingArea renderingArea;

    private:
      /* Indicates whether or not we are in full-screen mode. */
      bool inFullScreen;
  };
}

#endif  // #ifndef INTERFACE_HPP
