/*
 * Second lesson: Draing a triangle and a square.
 */

#include <iostream>
#include <gtkmm/main.h>
#include <sstream>
#include <glibmm/error.h>
#include <exception>

#include "errors.hpp"
#include "interface.hpp"

/*
 * Main function of the program.
 * Entry:
 *   argc  Number of arguments.
 *   argv  Values of arguments.
 * Retourne :
 *   0 if everything went well.
 *   -1 in case of GLib error.
 *   -2 in case of OpenGL error.
 *   -3 in case of standard library error.
 *   -4 in case of a non standard error.
 */
int main (int argc, char** argv) {
  try {
    /* Events loop. */
    const Gtk::Main kit(argc, argv);
    Gtk::GL::init(argc, argv);

    /* Main window. */
    Interface::MainWindow mainWindow;

    kit.run(mainWindow);

    return 0;
  }
  catch(const Glib::Error &ex) {
    /* Error message. */
    std::ostringstream message;
    message << "GLib error: " <<  ex.what() << '\n';
    g_critical(message.str().c_str());
    return -1;
  }
  catch (const Errors::InterfaceError &e) {
    /* Error message. */
    std::stringstream message;
    message << "OpenGL error: " << e.what() << ".\n";
    g_critical(message.str().c_str());
    return -2;
  }
  catch (const std::exception &e) {
    /* Error message. */
    std::stringstream message;
    message << "Standard library error: " << e.what()
            << '\n';
    g_critical(message.str().c_str());
    return -3;
  }
  catch (...) {
    g_critical("Non-standard exception.\n");
    return -4;
  }
}
